nexpose-client-python
=====================

This is the official Python package for the Python Nexpose API client
library.

For assistance with using the library, to share your scripts, or to
discuss different approaches, please visit the Rapid7 community:
https://community.rapid7.com/

Check out the
`wiki <https://github.com/rapid7/nexpose-client-python/wiki>`__ for
walk-throughs and other documentation. Submit bugs and feature requests
on the
`issues <https://github.com/rapid7/nexpose-client-python/issues>`__
page.

This library provides calls to the Nexpose XML APIs version 1.1 and 1.2.

nexpose-client-python uses `Semantic Versioning <http://semver.org/>`__.
This allows for confident use of `version
pinning <https://www.python.org/dev/peps/pep-0440/#version-specifiers>`__
in your requirements file.

Release Notes
-------------

Release notes are available on the
`Releases <https://github.com/rapid7/nexpose-client-python/releases>`__
page.

Contributions
-------------

We welcome contributions to this package. Please see
`CONTRIBUTING <https://github.com/rapid7/nexpose-client-python/blob/master/.github/CONTRIBUTING.md>`__ for details.

License
-------

The nexpose-client-python library is provided under the 3-Clause BSD
License. See `LICENSE <https://github.com/rapid7/nexpose-client-python/blob/master/LICENSE>`__ for details.

Credits
-------

| Davinsi Labs
| Rapid7, Inc.

See `contributors <https://github.com/rapid7/nexpose-client-python/blob/master/contributors.md>`__ for more info.
